@@ -5,6 +5,7 @@
     VIF=FALSE, COR=FALSE,
     SINK=FALSE, species.name="Species001",
     difference=FALSE, variables.alone=FALSE,
+    ENSEMBLE.tune=FALSE,
     ENSEMBLE.best=0, ENSEMBLE.min=0.7, ENSEMBLE.exponent=1,
     input.weights=NULL,
     MAXENT=1, MAXLIKE=1, GBM=1, GBMSTEP=0, RF=1, GLM=1, GLMSTEP=1, GAM=1, GAMSTEP=1, MGCV=1, 
@@ -104,7 +105,7 @@
         PLOTS=FALSE, evaluations.keep=T, models.keep=F,
         VIF=VIF, COR=COR,
         formulae.defaults=T, maxit=maxit,
-        AUC.weights=T,
+        ENSEMBLE.tune=ENSEMBLE.tune,
         ENSEMBLE.best=ENSEMBLE.best, ENSEMBLE.min=ENSEMBLE.min,
         ENSEMBLE.exponent=ENSEMBLE.exponent,
         input.weights=input.weights,
@@ -360,7 +361,7 @@
         PLOTS=FALSE, evaluations.keep=T,  
         VIF=VIF, COR=COR,
         formulae.defaults=T, maxit=maxit,
-        AUC.weights=T,
+        ENSEMBLE.tune=ENSEMBLE.tune,
         ENSEMBLE.best=ENSEMBLE.best, ENSEMBLE.min=ENSEMBLE.min,
         ENSEMBLE.exponent=ENSEMBLE.exponent,
         input.weights=input.weights,
@@ -572,7 +573,7 @@
         PLOTS=FALSE, evaluations.keep=T,  
         VIF=VIF, COR=COR,
         formulae.defaults=T, maxit=maxit,
-        AUC.weights=T,
+        ENSEMBLE.tune=ENSEMBLE.tune,
         ENSEMBLE.best=ENSEMBLE.best, ENSEMBLE.min=ENSEMBLE.min,
         ENSEMBLE.exponent=ENSEMBLE.exponent,
         input.weights=input.weights,
